GroupedInstructionDecoder

Struct GroupedInstructionDecoder 

pub struct GroupedInstructionDecoder { /* private fields */ }
Divides instruction matching search space in groups, indexed by the most significant bits of their encoding.

Instruction matching is in O(N / (head_bit_count ^ 2)) (if instructions most significant bits are uniformely distributed, which is not the case for Arm 32 bit encodings).

Implementations

Source

impl GroupedInstructionDecoder

pub fn new(head_bit_count: u8) -> Self

pub fn try_from_basic_decoder( head_bit_count: u8, version: ArmVersion, ) -> Result<Self, GroupingError>

pub fn try_insert( &mut self, pattern: &InstructionPattern, encoding: Encoding, f: fn(Encoding, u32, ItState) -> Result<Rc<dyn Instruction>, DecodeError>, ) -> Result<(), GroupingError>

Inserts an instruction decoding function given its corresponding pattern and encoding. A group is determined from pattern and f is stored into that group for further fast lookup.

If the group the instruction belong to cannot be determined, a GroupingError is returned.

pub fn try_insert_from_decoder_entry( &mut self, entry: &BasicDecoderEntry, ) -> Result<(), GroupingError>