pub struct Lut16InstructionDecoder { /* private fields */ }Expand description
Instruction decoder with a look-up-table for 16-bit instruction decoding.
This has 16-bit instruction decoding O(1) complexity, but has a strong cost during initialization to generate the table. The table is initialized using a given base instruction decoder.
The look-up table is only valid outside IT blocks. 16-bit instructions inside an IT block are resolved using the given base decoder.
32-bit wide instructions are resolved using the given base instruction decoder.
Implementations
Sourceimpl Lut16InstructionDecoder
impl Lut16InstructionDecoder
pub fn new(version: ArmVersion) -> Self